@@ -1,7 +1,7 @@
 from typing import Any, cast, Dict, Optional, Union
 
 from gitlab import exceptions as exc
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import (
     CreateMixin,
     DeleteMixin,
@@ -12,6 +12,7 @@ from gitlab.mixins import (
     SubscribableMixin,
     UpdateMixin,
 )
+from gitlab.types import RequiredOptional
 
 __all__ = [
     "GroupLabel",
